@@ -3,7 +3,6 @@ import json
 import pandas as pd
 import datetime
 from IPython.display import clear_output
-import plotly.express as px
 import time
 from sqlalchemy import create_engine
 from sqlalchemy.exc import IntegrityError
@@ -539,7 +538,6 @@ def vista_weekly_update_script(cypher_key,search_api_wait=10):
   rebirth_query2 = "UPDATE VISTA_MASTER SET status_on = '" + str(datetime.datetime.today()) +"' WHERE slug in " + str(tuple(added_slugs))  + " AND listing_status = 'DELISTED'"
   vista_sql_destructive(rebirth_query2,cypher_key)
 
-
   # A Summary of the updates
   final_success_response = {
       "No of Added Villas" : len(added_slugs),
@@ -550,23 +548,34 @@ def vista_weekly_update_script(cypher_key,search_api_wait=10):
 
   return final_success_response
 
-# Breadth first seach algorithm to see the blocekd dates
+# Breadth first seach algorithm to get the blocked dates
+
 def vista_blocked_dates(property_id,ci,co):
-  rg = (datetime.datetime.strptime(co, "%Y-%m-%d") - datetime.datetime.strptime(ci, "%Y-%m-%d")).days    #Range
 
-  steps = 0
+  # check if the listing is 
 
-  DTE = [(ci,co,rg)]                  # This list will contain all the date ranges to be checked - there will be additions and subtractions to this list
+  if vista_check_if_inactive(property_id) == "Probably Inactive":
+    return {
+        "blocked_dates" : "Probably Inactive"   
+    }
 
-  blocked = []
+  rg = (datetime.datetime.strptime(co, "%Y-%m-%d") - datetime.datetime.strptime(ci, "%Y-%m-%d")).days    # Range => checkout - checkin (in days)
+
+  api_calls = 0
+
+  DTE = [(ci,co,rg)]                  # This list contains all the date ranges to be checked - there will be additions and subtractions to this list
+
+  blocked = {}                         # we will add the blocekd dates here
   explored = []
 
+
   while len(DTE) != 0:
 
-    steps += 1
+    api_calls += 1                        # To see how many API calls happened (fewer the better)
 
-    print("Dates to Check: ", DTE)
-    dates = DTE.pop()
+    dates = DTE.pop()                     # Pick one item (date range) from the DTE list -> to see if it is available
+
+    print(f"Checking : {dates[0]} for {dates[2]} days")
 
     explored.append(dates)
 
@@ -574,15 +583,18 @@ def vista_blocked_dates(property_id,ci,co):
     checkout = dates[1]
     range = dates[2]
 
-    api_response = vista_price_calculator_api(property_id=property_id,checkin=checkin,checkout=checkout)
+    api_response = vista_price_calculator_api(property_id=property_id,checkin=checkin,checkout=checkout)      # Call the vista API to see of this is available
 
-    if "error" not in api_response.keys():
+    if "error" not in api_response.keys():                      # If no error -> it is available, start the next iteration of the loop
+      print("Not Blocked")
       continue
 
-    else:
-      if range == 1:
-        blocked.append((checkin,api_response['data']['price']['amount_to_be_paid']))
-      else:
+    else:                                                       # if the range is unavailable  do this
+      print("Blocked")
+      if range == 1:                                                                 # if the range is 1, mark the date as blocked
+        blocked[checkin] = api_response['data']['price']['amount_to_be_paid']
+        #blocked.append((checkin,api_response['data']['price']['amount_to_be_paid']))
+      else:                                                                           # if the range is not 1, split the range in half and add both these ranges to the DTE list
         checkin_t = datetime.datetime.strptime(checkin, "%Y-%m-%d")
         checkout_t = datetime.datetime.strptime(checkout, "%Y-%m-%d")
 
@@ -595,18 +607,43 @@ def vista_blocked_dates(property_id,ci,co):
 
 
   response_obj = {
-      "blocked_dates_and_price" : blocked,
+      "blocked_dates" : blocked,
       "meta_data": {
           "total_blocked_dates" : len(blocked),
-          "api_calls":steps,
-          "from": ci,
-          "to":co
+          "api_calls":api_calls,
+          "checked from": ci,
+          "checked till":co
           #"date_ranges_checked":explored
       }
   }
 
   return response_obj
 
+def vista_check_if_inactive(property_id="",slug=""):
+
+  if len(slug)>0:
+    try:
+      listing = vista_listing_api(slug)
+      property_id = listing['data']['property_detail']['id']
+    except: 
+      print("invalid listing or a delisted property")
+
+  min_nights = 1
+
+  for i in [8,16,32,64,128]:
+    price = vista_price_calculator_api(property_id , checkin=datetime.date.today()+datetime.timedelta(i), checkout = datetime.date.today()+datetime.timedelta(i + min_nights))
+    
+    if "error" not in price.keys():
+      return "Active"
+    
+    elif price['error'] == 'Booking Not Available for these dates':
+      pass
+    
+    elif type(price['error'].split(" ")[4]) == "int":
+      min_nights = price['error'].split(" ")[4]
+
+    return "Probably Inactive"
+
 """# Lohono
 
 
